%define ALD_Ver		1.2.4

%define OrgName udev
Name:         uC-%{OrgName}

License:      GPL LGPL
Summary:      udev - Linux userspace device management
Group:        System Environment/Base
Version:      175
Release:      1025.0

Source: %{OrgName}-%{version}.tar.xz
Source1: CROSS-uC.sh
#Patch0: %{OrgName}-%{version}-v4l_id.patch

%define DestDir		/Embedded/uC-%{uC_Version}
%define uC_Version 1.0.25

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
# -----------------------------------------------------

%define _prefix /usr/uC/%{uC_Version}/static

%define _bindir /%{_lib}/udev
%define _sbindir /sbin
%define _libexecdir /%{_lib}/udev
%define _mandir /usr/share/man/
%define _libdir %{_prefix}/lib
%define _defaultdocdir /usr/share/doc/
%define docdir %{_defaultdocdir}/%{OrgName}

#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/usr/uC/%{uC_Version}/static/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}/usr/uC/%{uC_Version}/static/share/doc
%define cross_docdir	%{cross_defaultdocdir}/%{OrgName}

%define CrossDestDir	/Cross

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir %{nil}
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-uclibc
%define target_  %{nil}

%endif # !_CROSS

# ------------------- description ------------------------------------
%description
udev - Linux userspace device management
#-------------------------------
%package cdrom
Summary:      udev cdrom
Group:        Development/Libraries
%description cdrom
udev cdrom
#-------------------------------
%package keymap
Summary:      udev keymap
Group:        Development/Libraries
%description keymap
udev keymap
#-------------------------------
%package devel
Summary:      uClibc Libraries for the C compiler
Group:        Development/Libraries
%description devel
These libraries are needed to compile C code.
# --------------------------------------
%package doc
Summary:      doc for %{OrgName}
Group:        Documentation
%description doc
doc for %{OrgName}

#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}
#patch0 -b .orig -p0
sed -i s:"@libexecdir@":"@sbindir@": init/udev.service.in

# ------------------- Build ------------------------------------------
%Build
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
UCLIBC_GCC_INC_SKIP=%{csysdir}/usr/include
export PATH GCC_NoHostPath UCLIBC_GCC_INC_SKIP


GCC_VER_STR=`%{target_}gcc -dumpversion`
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`

%if %{_arch} == "i386"
case $GCC_VER_STR in
  5.*) OPTFLAGS="-Os -march=i586" ;;
  4.9.*) OPTFLAGS="-Os -march=i586" ;;
  *)     OPTFLAGS="-Os -march=i486" ;;
esac
OPTFLAGS="$OPTFLAGS -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer $OPT47"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os $OPT47"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access $OPT47"
%endif

CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -fno-stack-protector -std=gnu99"
LDFLAGS="-Wl,--gc-sections"
CXXFLAGS="$OPTFLAGS"

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--enable-static \
	--disable-shared \
	--disable-silent-rules \
	--disable-libtool-lock \
	--disable-debug \
	--disable-logging \
	--disable-gudev \
	--disable-introspection \
	--disable-mtd_probe \
	--with-usb-ids-path=/usr/share/usb.ids \
	--with-pci-ids-path=/usr/share/pci.ids \
	--with-firmware-path=/usr/lib/hotplug/firmware:/lib/firmware \
	&>FConfigure_log.txt

make &>FMake_log.txt


# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
UCLIBC_GCC_INC_SKIP=%{csysdir}/usr/include
export PATH GCC_NoHostPath UCLIBC_GCC_INC_SKIP

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

rm $RPM_BUILD_ROOT%{_libdir}/*.la

cp README $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

mv $RPM_BUILD_ROOT/%{_lib}/udev/udevd $RPM_BUILD_ROOT/sbin/
mv $RPM_BUILD_ROOT%{_datadir}/doc/udev/README.keymap.txt $RPM_BUILD_ROOT%{docdir}/
mv $RPM_BUILD_ROOT%{_datadir}/gtk-doc/html/libudev $RPM_BUILD_ROOT%{docdir}/html
rm -r $RPM_BUILD_ROOT%{_datadir}/doc
rm -r $RPM_BUILD_ROOT%{_datadir}/gtk-doc

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
rm -r $RPM_BUILD_ROOT%{csysdir}/etc
rm -r $RPM_BUILD_ROOT%{csysdir}/%{_lib}
rm -r $RPM_BUILD_ROOT%{cross_sbindir}
rm -r $RPM_BUILD_ROOT%{cross_mandir}
mv $RPM_BUILD_ROOT%{csysdir}%{docdir}/* $RPM_BUILD_ROOT%{cross_docdir}/
rm -r $RPM_BUILD_ROOT%{cross_datadir}/gtk-doc
rm -r $RPM_BUILD_ROOT%{csysdir}/usr/share
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-cdrom-$SE $DD/%{name}-cdrom-$DE
  mv %{name}-keymap-$SE $DD/%{name}-keymap-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
popd

%if %{BUILD_TAR}
# --------------- build *.tgz ------------------------
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r etc %{_lib} sbin usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- post ------------------------------------------
%if %{_lib} != "lib"
%post
if test ! -e /lib/udev ; then
  mkdir -p /lib/udev
  pushd /lib/udev >/dev/null
    ln -s /%{_lib}/udev/rules.d
  popd >/dev/null
fi
%endif  #!BUILD_LOCAL_CROSS

# ------------------- Files ------------------------------------------
%files
%exclude /%{_lib}/udev/rules.d/60-cdrom_id.rules
/etc
/%{_lib}/udev/devices
/%{_lib}/udev/rules.d/4*
/%{_lib}/udev/rules.d/5*
/%{_lib}/udev/rules.d/6*
/%{_lib}/udev/rules.d/7*
/%{_lib}/udev/rules.d/8*
/%{_lib}/udev/rules.d/95-udev-late.rules

/%{_lib}/udev/accelerometer
/%{_lib}/udev/ata_id
/%{_lib}/udev/collect
/%{_lib}/udev/firmware
/%{_lib}/udev/pci-db
/%{_lib}/udev/scsi_id
/%{_lib}/udev/usb-db
/%{_lib}/udev/v4l_id
/sbin
%{docdir}/COPYING
%{docdir}/README
%{_mandir}

%files cdrom
/%{_lib}/udev/cdrom_id
/%{_lib}/udev/rules.d/60-cdrom_id.rules

%files keymap
/%{_lib}/udev/keymaps
/%{_lib}/udev/findkeyboards
/%{_lib}/udev/keyboard-force-release.sh
/%{_lib}/udev/keymap
/%{_lib}/udev/rules.d/95-keyboard-force-release.rules
/%{_lib}/udev/rules.d/95-keymap.rules
%{docdir}/README.keymap.txt

%files devel
%{_includedir}
%{_libdir}/*.a
%{_libdir}/pkgconfig
%{_datadir}/pkgconfig

%files doc
%{docdir}/html

%if %{BUILD_LOCAL_CROSS}
%Files %{TO_ARCH}
%{cross_libdir}
%{cross_includedir}
%{cross_datadir}/pkgconfig
%{cross_docdir}
%endif
